@@ -1,6 +1,6 @@
 """Модуль определяющий стандартные реализованные события."""
 from pywood.events import BaseEvent
-from pywood.updates.commands import is_command
+from pywood.updates.commands import is_command, is_start_command
 from pywood.updates.numbers import is_int_number
 from pywood.updates.texts import is_msg_w_text_to_bot
 
@@ -8,7 +8,8 @@ __all__ = [
     'IncomingText',
     'IncomingCommand',
     'IncomingIntNumber',
-    'IncomingUpdate'
+    'IncomingUpdate',
+    'IncomingStartCommand',
 ]
 
 
@@ -35,6 +36,13 @@ class IncomingCommand(BaseEvent):
     def happened(update) -> bool:
         return is_command(update)
 
+class IncomingStartCommand(BaseEvent):
+    """Входящая команда `start`."""
+
+    @staticmethod
+    def happened(update) -> bool:
+        return is_start_command(update)
+
 
 class IncomingIntNumber(BaseEvent):
     """Число."""
