@@ -13,13 +13,18 @@ class BaseState(metaclass=ABCMeta):
     """
 
     @property
-    def state_name(self):
+    def class_name(self):
         return self.__class__.__name__
 
     @classmethod
     def classname(cls):
         return cls.__name__
 
+    def bla(self_or_cls): # noqa
+        return self_or_cls.__class__.__name__
+
+
+
     def _handlers(self) -> List[Tuple[str, Callable]]:
         """Получить методы которые декорированы декораторами event и events."""
 
